'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.bemjsonMethod = bemjsonMethod;

var _utils = require('./utils');

function validateBEMJSON(bemjson, entity, bemNaming) {
    // retrieve and prepare className
    var className = (0, _utils.prepareClassName)(entity);

    // retrieve entities
    var entities = (0, _utils.getEntitiesFromBEMJSON)(bemjson);

    var isValidBlocks = entities.blocks.every(function (blockName) {
        return className.some(function (item) {
            // ignore if not block
            if (!bemNaming.isBlock(item)) {
                return false;
            }

            var parsedItem = bemNaming.parse(item);

            return parsedItem.block === blockName;
        });
    });

    if (!isValidBlocks) {
        return false;
    }

    var isValidElems = entities.elems.every(function (bemjsonEntity) {
        return className.some(function (item) {
            // ignore if not element
            if (!bemNaming.isElem(item)) {
                return false;
            }

            var parsedItem = bemNaming.parse(item);

            return parsedItem.block === bemjsonEntity.block && parsedItem.elem === bemjsonEntity.elem;
        });
    });

    if (!isValidElems) {
        return false;
    }

    var isValidMods = entities.mods.every(function (bemjsonEntity) {
        var block = bemjsonEntity.block;
        var elem = bemjsonEntity.elem;
        var modName = bemjsonEntity.modName;

        var modVal = String(bemjsonEntity.modVal);

        return className.some(function (item) {
            // ignore if no mods
            if (!bemNaming.isBlockMod(item) && !bemNaming.isElemMod(item)) {
                return false;
            }

            var parsedItem = bemNaming.parse(item);

            return parsedItem.block === block && parsedItem.elem === elem && parsedItem.modName === modName && String(parsedItem.modVal) === modVal;
        });
    });

    return isValidMods;
}

function bemjsonMethod(bemNaming, chai, entityHook) {
    var assert = chai.assert;
    var typeOf = assert.typeOf;


    return function (bemjson) {
        var entity = entityHook(this._obj);

        // check input
        assert((0, _utils.isValidEntity)(entity), entity + ' is neither a DOM element nor a className');
        typeOf(bemjson, 'object');

        this.assert(validateBEMJSON(bemjson, entity, bemNaming), 'expected #{this} to be #{exp} bemjson', 'expected #{this} to not be #{exp} bemjson', bemjson, entity);
    };
}