'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.blockProperty = blockProperty;
exports.blockMethod = blockMethod;

var _utils = require('./utils');

function blockProperty(bemNaming, chai, entityHook) {
    var assert = chai.assert;


    return function () {
        var entity = entityHook(this._obj);

        // check input
        assert((0, _utils.isValidEntity)(entity), entity + ' is neither a DOM element nor a className');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // check block
        this.assert(className.some(function (item) {
            return bemNaming.isBlock(item);
        }), 'expected #{this} to be a block but got #{act}', 'expected #{this} to not be a block but got #{act}', entity, entity);
    };
}

function blockMethod(bemNaming, chai, entityHook) {
    var assert = chai.assert;
    var typeOf = assert.typeOf;


    return function (blockName) {
        var entity = entityHook(this._obj);

        // check input
        assert((0, _utils.isValidEntity)(entity), entity + ' is neither a DOM element nor a className');
        typeOf(blockName, 'string');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // check block
        this.assert(className.some(function (item) {
            // ignore if not block
            if (!bemNaming.isBlock(item)) {
                return false;
            }

            var parsedItem = bemNaming.parse(item);

            return parsedItem.block === blockName;
        }), 'expected #{this} to be #{exp} block but got #{act}', 'expected #{this} to not be #{exp} block but got #{act}', blockName, entity);
    };
}