'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.elemProperty = elemProperty;
exports.elemMethod = elemMethod;

var _utils = require('./utils');

function elemProperty(bemNaming, chai, entityHook) {
    var assert = chai.assert;


    return function () {
        var entity = entityHook(this._obj);

        // check input
        assert((0, _utils.isValidEntity)(entity), entity + ' is neither a DOM element nor a className');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // check block
        this.assert(className.some(function (item) {
            return bemNaming.isElem(item);
        }), 'expected #{this} to be an element but got #{act}', 'expected #{this} to not be an element but got #{act}', entity, entity);
    };
}

function elemMethod(bemNaming, chai, entityHook) {
    var assert = chai.assert;
    var typeOf = assert.typeOf;


    return function (bemjson) {
        var entity = entityHook(this._obj);

        // check input
        assert((0, _utils.isValidEntity)(entity), entity + ' is neither a DOM element nor a className');
        typeOf(bemjson, 'object');

        // retrieve and prepare className
        var className = (0, _utils.prepareClassName)(entity);

        // check element
        this.assert(className.some(function (item) {
            // ignore if not element
            if (!bemNaming.isElem(item)) {
                return false;
            }

            var parsedItem = bemNaming.parse(item);

            return parsedItem.block === bemjson.block && parsedItem.elem === bemjson.elem;
        }), 'expected #{this} to be an elem #{exp} but got #{act}', 'expected #{this} to not be an elem of #{exp} block, but got #{act}', bemjson, entity);
    };
}